==> haskell-rio-orphans-0.1.2.0-417-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rio-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rio-orphans
version:              0.1.2.0
visibility:           public
id:                   rio-orphans-0.1.2.0-J11Fcx9IIpAKrvNQNrKe7i
key:                  rio-orphans-0.1.2.0-J11Fcx9IIpAKrvNQNrKe7i
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio#readme
synopsis:             Orphan instances for the RIO type in the rio package
description:
    See README and Haddocks at <https://www.stackage.org/package/rio-orphans>

category:             Control
abi:                  b584e44123e5ed1da26123b3c16ece21
exposed:              True
exposed-modules:      RIO.Orphans
hidden-modules:       Paths_rio_orphans
import-dirs:          /usr/lib/ghc-9.4.8/site-local/rio-orphans-0.1.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/rio-orphans-0.1.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/rio-orphans-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rio-orphans
hs-libraries:         HSrio-orphans-0.1.2.0-J11Fcx9IIpAKrvNQNrKe7i
depends:
    base-4.17.2.1 exceptions-0.10.5
    fast-logger-3.2.3-DeT2TRpuu17FRRtRFZyjKS
    monad-control-1.0.3.1-1muznQSV14KveEnsCnoJt
    monad-logger-0.3.42-8qb2rjVodGvEUwPFGSvRJj
    resourcet-1.2.6-9JXf0ifNhclLJYQG5fNMEA
    rio-0.1.22.0-HqSi0tBn2zM8Y9UNcqBwtj
    transformers-base-0.4.6-4sFiAxABgpA4ZaU1ZWKFkZ
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:   /usr/share/doc/haskell-rio-orphans/html/rio-orphans.haddock
haddock-html:         /usr/share/doc/haskell-rio-orphans/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rio-orphans-0.1.2.0-418-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rio-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rio-orphans
version:              0.1.2.0
visibility:           public
id:                   rio-orphans-0.1.2.0-HPyeuPRP8PW4pStKV3at0q
key:                  rio-orphans-0.1.2.0-HPyeuPRP8PW4pStKV3at0q
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio#readme
synopsis:             Orphan instances for the RIO type in the rio package
description:
    See README and Haddocks at <https://www.stackage.org/package/rio-orphans>

category:             Control
abi:                  c5d5a5f2b3db037fcbe95fd544a80775
exposed:              True
exposed-modules:      RIO.Orphans
hidden-modules:       Paths_rio_orphans
import-dirs:          /usr/lib/ghc-9.4.8/site-local/rio-orphans-0.1.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/rio-orphans-0.1.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/rio-orphans-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rio-orphans
hs-libraries:         HSrio-orphans-0.1.2.0-HPyeuPRP8PW4pStKV3at0q
depends:
    base-4.17.2.1 exceptions-0.10.5
    fast-logger-3.2.3-DeT2TRpuu17FRRtRFZyjKS
    monad-control-1.0.3.1-1muznQSV14KveEnsCnoJt
    monad-logger-0.3.42-3EJ00GIPOmWLmCF8CIXrJ9
    resourcet-1.2.6-9JXf0ifNhclLJYQG5fNMEA
    rio-0.1.22.0-HqSi0tBn2zM8Y9UNcqBwtj
    transformers-base-0.4.6-4sFiAxABgpA4ZaU1ZWKFkZ
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:   /usr/share/doc/haskell-rio-orphans/html/rio-orphans.haddock
haddock-html:         /usr/share/doc/haskell-rio-orphans/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
